@@ -6,20 +6,19 @@
  *
  * Copyright (C) 2002 Gustavo Girldez <gustavo.giraldez@gmx.net>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +26,6 @@
 #endif
 
 #include "gdl-i18n.h"
-#include <libgnome/gnome-macros.h>
 #include <gdk/gdkx.h>
 
 #include "gdl-tools.h"
@@ -117,7 +115,7 @@ static guint master_signals [LAST_SIGNAL] = { 0 };
 
 /* ----- Private interface ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDockMaster, gdl_dock_master, GObject, G_TYPE_OBJECT);
+GDL_CLASS_BOILERPLATE (GdlDockMaster, gdl_dock_master, GObject, G_TYPE_OBJECT);
 
 static void
 gdl_dock_master_class_init (GdlDockMasterClass *klass)
@@ -293,7 +291,7 @@ gdl_dock_master_dispose (GObject *g_object)
         master->_priv = NULL;
     }
 
-    GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (g_object));
+    GDL_CALL_PARENT (G_OBJECT_CLASS, dispose, (g_object));
 }
 
 static void 
@@ -307,7 +305,7 @@ foreach_lock_unlock (GdlDockItem *item,
     if (gdl_dock_object_is_compound (GDL_DOCK_OBJECT (item)))
         gtk_container_foreach (GTK_CONTAINER (item),
                                (GtkCallback) foreach_lock_unlock,
-                               (gpointer) locked);
+                               GINT_TO_POINTER (locked));
 }
 
 static void
@@ -325,7 +323,7 @@ gdl_dock_master_lock_unlock (GdlDockMaster *master,
     /* just to be sure hidden items are set too */
     gdl_dock_master_foreach (master,
                              (GFunc) foreach_lock_unlock,
-                             (gpointer) locked);
+                             GINT_TO_POINTER (locked));
 }
 
 static void
@@ -462,9 +460,10 @@ gdl_dock_master_drag_motion (GdlDockItem *item,
         GtkWidget *widget;
         /* ok, now get the widget who owns that window and see if we can
            get to a GdlDock by walking up the hierarchy */
-        gdk_window_get_user_data (window, (gpointer *) &widget);
+        gdk_window_get_user_data (window, (gpointer) &widget);
         if (GTK_IS_WIDGET (widget)) {
-            while (widget && !GDL_IS_DOCK (widget))
+            while (widget && (!GDL_IS_DOCK (widget) || 
+	           GDL_DOCK_OBJECT_GET_MASTER (widget) != master))
                 widget = widget->parent;
             if (widget) {
                 gint win_w, win_h;
@@ -774,7 +773,7 @@ gdl_dock_master_add (GdlDockMaster *master,
 
         /* register to "locked" notification if the item has a grip,
          * and add the item to the corresponding hash */
-        if (GDL_DOCK_ITEM_HAS_GRIP (object)) {
+        if (GDL_DOCK_ITEM_HAS_GRIP (GDL_DOCK_ITEM (object))) {
             g_signal_connect (object, "notify::locked",
                               G_CALLBACK (item_notify_cb), master);
             item_notify_cb (object, NULL, master);
@@ -798,7 +797,7 @@ gdl_dock_master_remove (GdlDockMaster *master,
 
     /* remove from locked/unlocked hashes and property change if
      * that's the case */
-    if (GDL_IS_DOCK_ITEM (object) && GDL_DOCK_ITEM_HAS_GRIP (object)) {
+    if (GDL_IS_DOCK_ITEM (object) && GDL_DOCK_ITEM_HAS_GRIP (GDL_DOCK_ITEM (object))) {
         gint locked = COMPUTE_LOCKED (master);
         if (g_hash_table_remove (master->_priv->locked_items, object) ||
             g_hash_table_remove (master->_priv->unlocked_items, object)) {
